@@ -1574,7 +1574,7 @@ class MTLFrameDto(RiotApiResponse):
         super().__init__(**kwargs)
         self.events: List[MTLEventDto] = list(map(lambda x: MTLEventDto(**x), events))
         self.participantFrames: List[MTLParticipantFrameDto] = list(
-            map(lambda x: MTLParticipantFrameDto(**x), participantFrames)
+            map(lambda x: MTLParticipantFrameDto(**x), participantFrames.values())
         )
         self.timestamp = timestamp
 
